@@ -7,6 +7,7 @@ class SynchronizeRemoteNginxLogsWithLocalRepository:
     @staticmethod
     def process(source_server: Server, destination_server: Server) -> None:
         try:
+            print("Synchronizing files")
             for files in source_server.include_files:
                 sysrsync.run(
                     source=f"{source_server.source_path}{files}",
@@ -16,6 +17,7 @@ class SynchronizeRemoteNginxLogsWithLocalRepository:
                     sync_source_contents=False,
                     options=["-a"],
                 )
+            print("END Synchronizing files")
         except Exception as error:
             raise FilesSynchronizationError(
                 f"Files synchronization failed with source: {source_server.host}:{source_server.source_path} "
